@@ -5,7 +5,7 @@
 
 package XML::Compile::Translate::Template;
 use vars '$VERSION';
-$VERSION = '1.37';
+$VERSION = '1.38';
 
 use base 'XML::Compile::Translate';
 
@@ -766,7 +766,8 @@ sub _perlAny($$)
         }
     }
     elsif($kind eq 'complex' || $kind eq 'mixed')  # empty complex-type
-    {   push @lines, "$tag => {}";
+    {   # if there is an "occurs", then there can always be more than one
+        push @lines, $tag.' => '.($ast->{occur} ? '[{},]' : '{}');
     }
     elsif($kind eq 'collapsed') {;}
     elsif($kind eq 'union')    # union type
